@@ -4,4 +4,6 @@ from regrex import preprocess
 from regrex import transform
 from regrex import dataset
 from regrex import statistics
-from regrex import validation
\ No newline at end of file
+from regrex import validation
+from regrex import log
+from regrex import SingleLineFunction
\ No newline at end of file
